You will need CMake and Boost to build the libraries. This steps also apply when installing with Pip, as the distribution is a source code bundle.


``` 
sudo apt-get install -y python3-dev python3-pip python-pybind11
sudo apt-get install -y cmake libboost-all-dev libboost-log-dev libboost-log-dev libboost-program-options-dev libboost-regex-dev 
sudo apt-get install -y sudo apt install zlib1g-dev libyaml-cpp-dev git

```


or built locally downloading and building
```
https://github.com/mongodb/mongo-c-driver/tree/master/src/libbson
https://github.com/jbeder/yaml-cpp/
```
